embassy-stm32

Crates

git

Versions

stm32u535ce

Flavors

Filter

Enum Filter 

#[repr(u8)]
pub enum Filter { NoFilter = 0, Filter2 = 1, Filter4 = 2, Filter8 = 3, }
Tamper input debounce filter, shared by all external tamper channels (FLTCR.TAMPFLT).

Variants



NoFilter = 0

Tamper event is activated on the edge of the input transitioning to the active level (no internal pull-up).



Filter2 = 1

Tamper event is activated after 2 consecutive samples at the active level.



Filter4 = 2

Tamper event is activated after 4 consecutive samples at the active level.



Filter8 = 3

Tamper event is activated after 8 consecutive samples at the active level.